@@ -1,13 +1,10 @@
 import csv
 import json
 import os
-import shutil
-from io import BytesIO
 
 import attr
 import click
 import logbook
-import jsonlines
 from tabulate import tabulate
 
 from tqdm import tqdm
