@@ -31,3 +31,13 @@ class RegistryKeyNotFoundException(RegipyException):
 class UnidentifiedHiveException(RegipyException):
     pass
 
+
+class RegistryRecoveryException(RegipyException):
+    pass
+
+
+class RegistryParsingException(RegipyException):
+    """
+    Raised when there is a parsing error, most probably a corrupted hive
+    """
+    pass
